@@ -61,8 +61,6 @@ GRL_LOG_DOMAIN_STATIC(bookmarks_log_domain);
 
 /* --- Plugin information --- */
 
-#define PLUGIN_ID   BOOKMARKS_PLUGIN_ID
-
 #define SOURCE_ID   "grl-bookmarks"
 #define SOURCE_NAME _("Bookmarks")
 #define SOURCE_DESC _("A source for organizing media bookmarks")
@@ -154,7 +152,7 @@ grl_bookmarks_plugin_register_keys (GrlRegistry *registry,
                              G_TYPE_DATE_TIME,
                              G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE),
   GRL_BOOKMARKS_KEY_BOOKMARK_TIME =
-      grl_registry_register_metadata_key (registry, spec, NULL);
+    grl_registry_register_metadata_key (registry, spec, GRL_METADATA_KEY_INVALID, NULL);
   /* If key was not registered, could be that it is already registered. If so,
      check if type is the expected one, and reuse it */
   if (GRL_BOOKMARKS_KEY_BOOKMARK_TIME == GRL_METADATA_KEY_INVALID) {
@@ -168,10 +166,18 @@ grl_bookmarks_plugin_register_keys (GrlRegistry *registry,
   }
 }
 
- GRL_PLUGIN_REGISTER_FULL (grl_bookmarks_plugin_init,
-                           NULL,
-                           grl_bookmarks_plugin_register_keys,
-                           PLUGIN_ID);
+GRL_PLUGIN_DEFINE (GRL_MAJOR,
+                   GRL_MINOR,
+                   BOOKMARKS_PLUGIN_ID,
+                   "Bookmarks",
+                   "A plugin for organizing media bookmarks",
+                   "Igalia S.L.",
+                   VERSION,
+                   "LGPL",
+                   "http://www.igalia.com",
+                   grl_bookmarks_plugin_init,
+                   NULL,
+                   grl_bookmarks_plugin_register_keys);
 
  /* ================== Bookmarks GObject ================ */
 
@@ -332,19 +338,19 @@ build_media_from_resource (GrlMedia      *content,
 
   if (!media) {
     if (type == BOOKMARK_TYPE_CATEGORY) {
-      media = GRL_MEDIA (grl_media_box_new ());
+      media = grl_media_container_new ();
     } else if (mime_is_audio (mime)) {
       if (type_filter & GRL_TYPE_FILTER_AUDIO)
-        media = GRL_MEDIA (grl_media_new ());
+        media = grl_media_new ();
     } else if (mime_is_video (mime)) {
       if (type_filter & GRL_TYPE_FILTER_VIDEO)
-        media = GRL_MEDIA (grl_media_new ());
+        media = grl_media_new ();
     } else if (mime_is_image (mime)) {
       if (type_filter & GRL_TYPE_FILTER_IMAGE)
-        media = GRL_MEDIA (grl_media_image_new ());
+        media = grl_media_image_new ();
     } else {
       if (type_filter != GRL_TYPE_FILTER_NONE)
-        media = GRL_MEDIA (grl_media_new ());
+        media = grl_media_new ();
     }
   }
 
@@ -669,7 +675,7 @@ find_resource (const gchar   *id,
 static void
 store_bookmark (GrlBookmarksSource *bookmarks_source,
                 GList **keylist,
-                GrlMediaBox *parent,
+                GrlMedia *parent,
                 GrlMedia *bookmark,
                 GError **error)
 {
@@ -710,7 +716,7 @@ store_bookmark (GrlBookmarksSource *bookmarks_source,
 
   GRL_DEBUG ("URL: '%s'", url);
 
-  if (GRL_IS_MEDIA_BOX (bookmark)) {
+  if (grl_media_is_container (bookmark)) {
     type = BOOKMARK_TYPE_CATEGORY;
   } else {
     type = BOOKMARK_TYPE_STREAM;
