@@ -143,7 +143,7 @@ grl_daap_plugin_init (GrlRegistry *registry,
 GRL_PLUGIN_DEFINE (GRL_MAJOR,
                    GRL_MINOR,
                    DAAP_PLUGIN_ID,
-                   "DMAP",
+                   "DAAP",
                    "A plugin for browsing DAAP servers",
                    "W. Michael Petullo",
                    VERSION,
@@ -176,6 +176,7 @@ grl_daap_source_new (DMAPMdnsBrowserService *service)
                          "source-id",   source_id,
                          "source-name", service->name,
                          "source-desc", source_desc,
+                         "supported-media", GRL_SUPPORTED_MEDIA_AUDIO,
                          NULL);
 
   source->priv->service = service;
