@@ -44,8 +44,6 @@ GRL_LOG_DOMAIN_STATIC(freebox_log_domain);
 
 /* --- Plugin information --- */
 
-#define PLUGIN_ID   FREEBOX_PLUGIN_ID
-
 #define TV_SOURCE_ID   "grl-freeboxtv"
 #define TV_SOURCE_NAME _("Freebox TV")
 #define TV_SOURCE_DESC _("A source for browsing Freebox TV channels")
@@ -169,9 +167,18 @@ grl_freebox_plugin_init (GrlRegistry *registry,
   return TRUE;
 }
 
-GRL_PLUGIN_REGISTER (grl_freebox_plugin_init,
-                     NULL,
-                     PLUGIN_ID);
+GRL_PLUGIN_DEFINE (GRL_MAJOR,
+                   GRL_MINOR,
+                   FREEBOX_PLUGIN_ID,
+                   "Freebox",
+                   "A plugin for Freebox TV channels",
+                   "GNOME",
+                   VERSION,
+                   "LGPL",
+                   "http://www.gnome.org",
+                   grl_freebox_plugin_init,
+                   NULL,
+                   NULL);
 
 /* ================== Freebox GObject ================ */
 
@@ -201,7 +208,7 @@ grl_freebox_source_new_tv (void)
                          "source-id", TV_SOURCE_ID,
                          "source-name", TV_SOURCE_NAME,
                          "source-desc", TV_SOURCE_DESC,
-                         "supported-media", GRL_MEDIA_TYPE_VIDEO,
+                         "supported-media", GRL_SUPPORTED_MEDIA_VIDEO,
                          "source-icon", icon,
                          "source-tags", tags,
                          NULL);
@@ -232,7 +239,7 @@ grl_freebox_source_new_radio (void)
                          "source-id", RADIO_SOURCE_ID,
                          "source-name", RADIO_SOURCE_NAME,
                          "source-desc", RADIO_SOURCE_DESC,
-                         "supported-media", GRL_MEDIA_TYPE_AUDIO,
+                         "supported-media", GRL_SUPPORTED_MEDIA_AUDIO,
                          "source-icon", icon,
                          "source-tags", tags,
                          NULL);
