@@ -67,7 +67,9 @@ typedef struct {
   OperationSpec *os;
 } UnzipOperation;
 
+#ifdef GOA_ENABLED
 static gpointer grl_lua_library_load_goa_data (lua_State *L);
+#endif
 
 /* ================== Lua-Library utils/helpers ============================ */
 
@@ -478,12 +480,13 @@ grl_util_fetch_done (GObject *source_object,
   lua_State *L = fo->L;
   OperationSpec *os = fo->os;
   gchar *fixed = NULL;
+  gboolean cancelled = FALSE;
 
   if (!grl_net_wc_request_finish (GRL_NET_WC (source_object),
                                   res, &data, &len, &err)) {
     if (g_error_matches (err, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
       GRL_DEBUG ("fetch operation was cancelled");
-      goto free_fetch_op;
+      cancelled = TRUE;
     }
     data = NULL;
   } else if (!g_utf8_validate(data, len, NULL)) {
@@ -501,7 +504,8 @@ grl_util_fetch_done (GObject *source_object,
   g_free (fixed);
 
   if (err != NULL) {
-    GRL_WARNING ("Can't fetch element %d (URL: %s): '%s'", fo->index + 1, fo->url, err->message);
+    if (!cancelled)
+      GRL_WARNING ("Can't fetch element %d (URL: %s): '%s'", fo->index + 1, fo->url, err->message);
     g_clear_error (&err);
   } else {
     GRL_DEBUG ("fetch_done element %d of %d urls", fo->index + 1, fo->num_urls);
@@ -512,12 +516,16 @@ grl_util_fetch_done (GObject *source_object,
     if (fo->results[i] == NULL) {
       /* Clean up this operation, and wait for
        * other operations to complete */
+      g_object_unref (fo->cancellable);
       g_free (fo->url);
       g_free (fo);
       return;
     }
   }
 
+  if (cancelled)
+    goto free_fetch_op;
+
   /* get the callback from the registry */
   lua_rawgeti (L, LUA_REGISTRYINDEX, fo->lua_callback);
 
@@ -1742,10 +1750,10 @@ grl_lua_library_save_goa_data (lua_State *L, gpointer goa_object)
  * @L: LuaState where the data is stored.
  * @return: The #GoaObject.
  **/
+#ifdef GOA_ENABLED
 static gpointer
 grl_lua_library_load_goa_data (lua_State *L)
 {
-#ifdef GOA_ENABLED
   GoaObject *goa_object;
 
   lua_getglobal (L, GOA_LUA_NAME);
@@ -1753,8 +1761,5 @@ grl_lua_library_load_goa_data (lua_State *L)
   lua_pop(L, 1);
 
   return goa_object;
-#else
-  GRL_WARNING ("grl_lua_library_load_goa_data() called but GOA support disabled.");
-  return NULL;
-#endif /* GOA_ENABLED */
 }
+#endif /* GOA_ENABLED */
