@@ -36,8 +36,6 @@
 #define GRL_LOG_DOMAIN_DEFAULT opensubtitles_log_domain
 GRL_LOG_DOMAIN_STATIC(opensubtitles_log_domain);
 
-#define PLUGIN_ID   OPENSUBTITLES_PLUGIN_ID
-
 #define SOURCE_ID   "grl-opensubtitles"
 #define SOURCE_NAME _("OpenSubtitles Provider")
 #define SOURCE_DESC _("A source providing a list of subtitles for a video")
@@ -90,6 +88,7 @@ gboolean grl_opensubtitles_source_plugin_init (GrlRegistry *registry,
 
 static GrlKeyID
 register_metadata_key (GrlRegistry *registry,
+                       GrlKeyID bind_key,
                        const char *name,
                        const char *nick,
                        const char *blurb)
@@ -104,7 +103,7 @@ register_metadata_key (GrlRegistry *registry,
                               G_PARAM_READWRITE
                               | G_PARAM_STATIC_STRINGS);
 
-  key = grl_registry_register_metadata_key (registry, spec, NULL);
+  key = grl_registry_register_metadata_key (registry, spec, bind_key, NULL);
 
   if (key == GRL_METADATA_KEY_INVALID) {
     key = grl_registry_lookup_metadata_key (registry, name);
@@ -131,12 +130,14 @@ grl_opensubtitles_source_plugin_init (GrlRegistry *registry,
 
   GRL_OPENSUBTITLES_METADATA_KEY_SUBTITLES_URL =
     register_metadata_key (registry,
+                           GRL_METADATA_KEY_INVALID,
                            "subtitles-url",
                            "subtitles-url",
                            "Subtitles URL");
 
   GRL_OPENSUBTITLES_METADATA_KEY_SUBTITLES_LANG =
     register_metadata_key (registry,
+                           GRL_METADATA_KEY_INVALID,
                            "subtitles-lang",
                            "subtitles-lang",
                            "Subtitles Language");
@@ -149,9 +150,18 @@ grl_opensubtitles_source_plugin_init (GrlRegistry *registry,
   return TRUE;
 }
 
-GRL_PLUGIN_REGISTER (grl_opensubtitles_source_plugin_init,
-                     NULL,
-                     PLUGIN_ID);
+GRL_PLUGIN_DEFINE (GRL_MAJOR,
+                   GRL_MINOR,
+                   OPENSUBTITLES_PLUGIN_ID,
+                   "OpenSubtitles Provider",
+                   "A plugin that gets a list of subtitles for a video",
+                   "Bastien Nocera",
+                   VERSION,
+                   "LGPL",
+                   "http://www.hadess.net",
+                   grl_opensubtitles_source_plugin_init,
+                   NULL,
+                   NULL);
 
 /* ================== GrlOpenSubtitles GObject ================ */
 
@@ -376,6 +386,10 @@ parse_results (GrlMedia    *media,
   data_val = g_hash_table_lookup (response, "data");
   if (!data_val)
     goto out;
+  if (!G_VALUE_HOLDS_BOXED (data_val)) {
+    GRL_DEBUG ("No matching subtitles in response");
+    goto out;
+  }
   data = g_value_get_boxed (data_val);
   subs = g_hash_table_new_full (g_str_hash, g_str_equal,
 				g_free, (GDestroyNotify) subtitle_data_free);
@@ -398,8 +412,8 @@ G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 
       episode = lookup_int (ht, "SeriesSeason");
       season = lookup_int (ht, "SeriesEpisode");
-      if (season != grl_media_video_get_episode (GRL_MEDIA_VIDEO (media)) ||
-          episode != grl_media_video_get_season (GRL_MEDIA_VIDEO (media))) {
+      if (season != grl_media_get_episode (media) ||
+          episode != grl_media_get_season (media)) {
         continue;
       }
     }
@@ -554,16 +568,16 @@ grl_opensubtitles_source_may_resolve (GrlSource *source,
       !grl_data_has_key (GRL_DATA (media), GRL_METADATA_KEY_SIZE)) {
     if (missing_keys) {
       GList *keys = NULL;
-      if (!grl_data_has_key (GRL_DATA (media), priv->hash_keyid))
+      if (!media || !grl_data_has_key (GRL_DATA (media), priv->hash_keyid))
         keys = g_list_prepend (keys, GRLKEYID_TO_POINTER (priv->hash_keyid));
-      if (!grl_data_has_key (GRL_DATA (media), GRL_METADATA_KEY_SIZE))
+      if (!media || !grl_data_has_key (GRL_DATA (media), GRL_METADATA_KEY_SIZE))
         keys = g_list_prepend (keys, GRLKEYID_TO_POINTER (GRL_METADATA_KEY_SIZE));
       *missing_keys = keys;
     }
     return FALSE;
   }
 
-  if (!GRL_IS_MEDIA_VIDEO (media))
+  if (!grl_media_is_video (media))
     return FALSE;
 
   if (grl_data_has_key (GRL_DATA (media), GRL_METADATA_KEY_SHOW)) {
