@@ -39,8 +39,6 @@
 #define GRL_LOG_DOMAIN_DEFAULT tmdb_log_domain
 GRL_LOG_DOMAIN(tmdb_log_domain);
 
-#define PLUGIN_ID   TMDB_PLUGIN_ID
-
 #define SOURCE_ID   "grl-tmdb"
 #define SOURCE_NAME "TMDb Metadata Provider"
 #define SOURCE_DESC "A source for movie metadata from themoviedb.org"
@@ -115,6 +113,7 @@ static void grl_tmdb_source_finalize (GObject *object);
 
 static GrlKeyID
 register_metadata_key (GrlRegistry *registry,
+                       GrlKeyID bind_key,
                        const char *name,
                        const char *nick,
                        const char *blurb);
@@ -168,33 +167,45 @@ grl_tmdb_source_plugin_register_keys (GrlRegistry *registry,
 {
   GRL_TMDB_METADATA_KEY_BACKDROP =
     register_metadata_key (registry,
+                           GRL_METADATA_KEY_INVALID,
                            "tmdb-backdrop",
                            "tmdb-backdrop",
                            "A list of URLs for movie backdrops");
 
   GRL_TMDB_METADATA_KEY_POSTER =
     register_metadata_key (registry,
+                           GRL_METADATA_KEY_INVALID,
                            "tmdb-poster",
                            "tmdb-poster",
                            "A list of URLs for movie posters");
 
   GRL_TMDB_METADATA_KEY_IMDB_ID =
     register_metadata_key (registry,
+                           GRL_METADATA_KEY_INVALID,
                            "tmdb-imdb-id",
                            "tmdb-imdb-id",
                            "ID of this movie at imdb.org");
 
   GRL_TMDB_METADATA_KEY_TMDB_ID =
     register_metadata_key (registry,
+                           GRL_METADATA_KEY_INVALID,
                            "tmdb-id",
                            "tmdb-id",
                            "ID of this movie at tmdb.org");
 }
 
-GRL_PLUGIN_REGISTER_FULL (grl_tmdb_source_plugin_init,
-                          NULL,
-                          grl_tmdb_source_plugin_register_keys,
-                          PLUGIN_ID);
+GRL_PLUGIN_DEFINE (GRL_MAJOR,
+                   GRL_MINOR,
+                   TMDB_PLUGIN_ID,
+                   "TMDb Metadata Provider",
+                   "A plugin to retrieve movie metadata from themoviedb.org",
+                   "Canonical Ltd.",
+                   VERSION,
+                   "LGPL",
+                   "http://www.canonical.com",
+                   grl_tmdb_source_plugin_init,
+                   NULL,
+                   grl_tmdb_source_plugin_register_keys);
 
 /* ================== GrlTmdbMetadata GObject ================ */
 
@@ -380,6 +391,7 @@ grl_tmdb_source_finalize (GObject *object)
 
 static GrlKeyID
 register_metadata_key (GrlRegistry *registry,
+                       GrlKeyID bind_key,
                        const char *name,
                        const char *nick,
                        const char *blurb)
@@ -394,7 +406,7 @@ register_metadata_key (GrlRegistry *registry,
                               G_PARAM_READWRITE
                               | G_PARAM_STATIC_STRINGS);
 
-  key = grl_registry_register_metadata_key (registry, spec, NULL);
+  key = grl_registry_register_metadata_key (registry, spec, bind_key, NULL);
 
   if (key == GRL_METADATA_KEY_INVALID) {
     key = grl_registry_lookup_metadata_key (registry, name);
@@ -717,8 +729,7 @@ on_request_ready (GObject *source,
   if (SHOULD_RESOLVE (GRL_METADATA_KEY_ORIGINAL_TITLE)) {
     value = grl_tmdb_request_get (request, "$.original_title");
     if (value != NULL) {
-      grl_media_video_set_original_title (GRL_MEDIA_VIDEO (closure->rs->media),
-                                          g_value_get_string (value));
+      grl_media_set_original_title (closure->rs->media, g_value_get_string (value));
       g_value_unset (value);
       g_free (value);
     }
@@ -855,8 +866,7 @@ on_request_ready (GObject *source,
       values = grl_tmdb_request_get_string_list (request, "$.casts.cast..name");
     iter = values;
     while (iter != NULL) {
-      grl_media_video_add_performer (GRL_MEDIA_VIDEO (closure->rs->media),
-                                     iter->data);
+      grl_media_add_performer (closure->rs->media, iter->data);
       iter = iter->next;
     }
     g_list_free_full (values, g_free);
@@ -872,8 +882,7 @@ on_request_ready (GObject *source,
                                                              producer_filter);
     iter = values;
     while (iter != NULL) {
-        grl_media_video_add_producer (GRL_MEDIA_VIDEO (closure->rs->media),
-                                      iter->data);
+        grl_media_add_producer (closure->rs->media, iter->data);
       iter = iter->next;
     }
     g_list_free_full (values, g_free);
@@ -889,8 +898,7 @@ on_request_ready (GObject *source,
                                                              director_filter);
     iter = values;
     while (iter != NULL) {
-      grl_media_video_add_director (GRL_MEDIA_VIDEO (closure->rs->media),
-                                    iter->data);
+      grl_media_add_director (closure->rs->media, iter->data);
       iter = iter->next;
     }
     g_list_free_full (values, g_free);
@@ -1076,8 +1084,7 @@ on_search_ready (GObject *source,
   if (SHOULD_RESOLVE (GRL_METADATA_KEY_ORIGINAL_TITLE)) {
     value = grl_tmdb_request_get (request, "$.results[0].original_title");
     if (value != NULL) {
-      grl_media_video_set_original_title (GRL_MEDIA_VIDEO (closure->rs->media),
-                                          g_value_get_string (value));
+      grl_media_set_original_title (closure->rs->media, g_value_get_string (value));
       g_value_unset (value);
       g_free (value);
     }
@@ -1269,7 +1276,7 @@ grl_tmdb_source_may_resolve (GrlSource *source,
     return FALSE;
 
   /* We can only entertain videos */
-  if (media && !GRL_IS_MEDIA_VIDEO (media))
+  if (media && !grl_media_is_video (media))
     return FALSE;
 
   /* Caller wants to check what's needed to resolve */
@@ -1304,14 +1311,14 @@ grl_tmdb_source_resolve (GrlSource *source,
   guint64 movie_id = 0;
   GList *it;
 
-  if (!GRL_IS_MEDIA_VIDEO (rs->media)) {
+  if (!grl_media_is_video (rs->media)) {
     /* We only entertain videos */
     rs->callback (source, rs->operation_id, rs->media, rs->user_data, NULL);
     return;
   }
 
   /* If the media is a TV show, don't handle it */
-  if (grl_media_video_get_show (GRL_MEDIA_VIDEO (rs->media)) != NULL) {
+  if (grl_media_get_show (rs->media) != NULL) {
     rs->callback (source, rs->operation_id, rs->media, rs->user_data, NULL);
     return;
   }
