@@ -70,7 +70,6 @@ struct _GrlTrackerSourcePriv {
   gboolean notify_changes;
 
   GrlTrackerSourceState state;
-  guint notification_ref;
 };
 
 /**/
@@ -79,7 +78,6 @@ extern GrlPlugin *grl_tracker_plugin;
 
 /* shared data across  */
 extern GrlTrackerCache *grl_tracker_item_cache;
-extern GHashTable *grl_tracker_source_sources_modified;
 extern gboolean grl_tracker_upnp_present;
 
 /* tracker plugin config */
