@@ -51,8 +51,6 @@ GRL_LOG_DOMAIN_STATIC(vimeo_log_domain);
 
 /* --- Plugin information --- */
 
-#define PLUGIN_ID   VIMEO_PLUGIN_ID
-
 #define SOURCE_ID   "grl-vimeo"
 #define SOURCE_NAME "Vimeo"
 #define SOURCE_DESC _("A source for browsing and searching Vimeo videos")
@@ -162,9 +160,18 @@ grl_vimeo_plugin_init (GrlRegistry *registry,
   return init_result;
 }
 
-GRL_PLUGIN_REGISTER (grl_vimeo_plugin_init,
-                     NULL,
-                     PLUGIN_ID);
+GRL_PLUGIN_DEFINE (GRL_MAJOR,
+                   GRL_MINOR,
+                   VIMEO_PLUGIN_ID,
+                   "Vimeo",
+                   "A plugin for searching Vimeo videos",
+                   "Igalia S.L.",
+                   VERSION,
+                   "LGPL",
+                   "http://www.igalia.com",
+                   grl_vimeo_plugin_init,
+                   NULL,
+                   NULL);
 
 /* ================== Vimeo GObject ================ */
 
@@ -189,7 +196,7 @@ grl_vimeo_source_new (void)
                          "source-id", SOURCE_ID,
                          "source-name", SOURCE_NAME,
                          "source-desc", SOURCE_DESC,
-                         "supported-media", GRL_MEDIA_TYPE_VIDEO,
+                         "supported-media", GRL_SUPPORTED_MEDIA_VIDEO,
                          "source-icon", icon,
                          "source-tags", tags,
                          NULL);
@@ -323,13 +330,13 @@ update_media (GrlMedia *media, GHashTable *video)
   str = g_hash_table_lookup (video, VIMEO_VIDEO_WIDTH);
   if (str)
   {
-    grl_media_video_set_width (GRL_MEDIA_VIDEO (media), str_to_gint (str));
+    grl_media_set_width (media, str_to_gint (str));
   }
 
   str = g_hash_table_lookup (video, VIMEO_VIDEO_HEIGHT);
   if (str)
   {
-    grl_media_video_set_height (GRL_MEDIA_VIDEO (media), str_to_gint (str));
+    grl_media_set_height (media, str_to_gint (str));
   }
 }
 
