@@ -504,7 +504,7 @@ build_media_from_entry (GrlYoutubeSource *source,
 
   /* Make sure we set the media id in any case */
   if (!grl_media_get_id (media)) {
-    grl_media_set_id (media, gdata_youtube_video_get_video_id (video));
+    grl_media_set_id (media, gdata_entry_get_id (entry));
   }
 
   iter = (GList *) keys;
@@ -562,15 +562,8 @@ build_media_from_entry (GrlYoutubeSource *source,
 	GRL_WARNING ("Failed to get video URL. totem-pl-parser error '%d'", res);
       g_clear_object (&parser);
     } else if (key == GRL_METADATA_KEY_EXTERNAL_PLAYER) {
-      GDataYouTubeContent *youtube_content;
-      youtube_content =
-	gdata_youtube_video_look_up_content (video,
-					     "application/x-shockwave-flash");
-      if (youtube_content != NULL) {
-        const gchar *uri =
-          gdata_media_content_get_uri (GDATA_MEDIA_CONTENT (youtube_content));
-	grl_media_set_external_player (media, uri);
-      }
+      const gchar *uri = gdata_youtube_video_get_player_uri (video);
+      grl_media_set_external_player (media, uri);
     }
     iter = g_list_next (iter);
   }
@@ -591,7 +584,6 @@ build_categories_directory_read_cb (GObject *source_object,
   guint total = 0;
   GList *all = NULL, *iter;
   CategoryInfo *cat_info;
-  gchar *id;
   guint index = 0;
 
   GRL_DEBUG (G_STRFUNC);
@@ -739,12 +731,12 @@ static void
 build_category_directory (BuildCategorySpec *bcs)
 {
   GrlYoutubeSource *source;
-  GDataService *service;
+  GDataYouTubeService *service;
 
   GRL_DEBUG (__FUNCTION__);
 
   source = GRL_YOUTUBE_SOURCE (bcs->source);
-  service = GDATA_SERVICE (source->priv->service);
+  service = GDATA_YOUTUBE_SERVICE (source->priv->service);
   gdata_youtube_service_get_categories_async (service, NULL,
                                               build_categories_directory_read_cb,
                                               bcs);
@@ -1076,7 +1068,7 @@ produce_from_feed (OperationSpec *os)
   service = GRL_YOUTUBE_SOURCE (os->source)->priv->service;
 
   /* Index in GData starts at 1 */
-  query = gdata_youtube_query_new (NULL);
+  query = GDATA_QUERY (gdata_youtube_query_new (NULL));
   gdata_query_set_start_index (query, os->skip + 1);
   gdata_query_set_max_results (query, os->count);
   os->category_info = &feeds_dir[feed_type];
@@ -1128,7 +1120,7 @@ produce_from_category (OperationSpec *os)
   service = GRL_YOUTUBE_SOURCE (os->source)->priv->service;
 
   /* Index in GData starts at 1 */
-  query = gdata_youtube_query_new (NULL);
+  query = GDATA_QUERY (gdata_youtube_query_new (NULL));
   gdata_query_set_start_index (query, os->skip + 1);
   gdata_query_set_max_results (query, os->count);
   os->category_info = &categories_dir[category_index];
@@ -1317,7 +1309,7 @@ grl_youtube_source_search (GrlSource *source,
   grl_operation_set_data (ss->operation_id, g_object_ref (os->cancellable));
 
   /* Index in GData starts at 1 */
-  query = gdata_youtube_query_new (ss->text);
+  query = GDATA_QUERY (gdata_youtube_query_new (ss->text));
   gdata_query_set_start_index (query, os->skip + 1);
   gdata_query_set_max_results (query, os->count);
 
